@@ -6,7 +6,7 @@ Clock.sendEvent = function (name)
 	document.dispatchEvent(event);
 }
 
-Clock.setStyleSheet = function (url)
+Clock.setStyleSheet = function (data)
 {
 	var link = document.getElementById('theme_css');
 
@@ -20,7 +20,7 @@ Clock.setStyleSheet = function (url)
 		document.head.insertBefore(link, document.head.firstChild);
 	}
 
-	link.setAttribute('href', url);
+	link.setAttribute('href', ('data:text/css;charset=utf-8;base64,' + window.btoa('html, body {margin: 0; padding: 0;} ' + data)));
 }
 
 Clock.setStyle = function (object, property, value)
